# frozen_string_literal: true

module Lintress

  # Parse the response from RuboCop
  class Parser
    attr_reader :offenses
    
    def initialize s
      @offenses = []
      @lines = s.lines
    end

    def parse
      # remove_pointer_lines
      @lines.delete_if do |line|
        line.match?(/^\s+[\^]*$/) || line.match?(/^\^+$/)
      end

      # catalogue_offenses
      # (filename):(line):(column) (char): (reason)
      @lines.each do |line|
        ptn = %r{(?<file>[\w/\.]+):(?<line>\d+):(?<col>\d+): \w: (?<reason>.*)}
        m = line.match ptn
        next unless m
        offense = Offense.new m
        @offenses << offense
      end
    end
  end

  class Offense
    attr_accessor :ofile, :oline, :ocolumn, :oreason

    def initialize opts
      @ofile = opts[:file]
      @oline = opts[:line]
      @ocolumn = opts[:col]
      @oreason = opts[:reason]
    end

    def to_s
      "#{ofile} at (#{oline}, #{ocolumn}) - #{oreason}"
    end
  end
end
